@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/osrs/libtiff/tools/tiff2rgba.c,v 1.5 2001/08/11 03:13:59 warmerda Exp $ */
+/* $Id: tiff2rgba.c,v 1.11 2004/11/03 00:28:24 fwarmerdam Exp $ */
 
 /*
  * Copyright (c) 1991-1997 Sam Leffler
@@ -24,10 +24,16 @@
  * OF THIS SOFTWARE.
  */
 
+#include "tif_config.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
 #include "tiffio.h"
 
 #define	streq(a,b)	(strcmp(a,b) == 0)
@@ -46,7 +52,7 @@ int     no_alpha = 0;
 
 
 static	int tiffcvt(TIFF* in, TIFF* out);
-static	void usage(void);
+static	void usage(int code);
 
 int
 main(int argc, char* argv[])
@@ -74,7 +80,7 @@ main(int argc, char* argv[])
             else if (streq(optarg, "zip"))
                 compression = COMPRESSION_DEFLATE;
             else
-                usage();
+                usage(-1);
             break;
 
           case 'r':
@@ -90,12 +96,12 @@ main(int argc, char* argv[])
             break;
             
           case '?':
-            usage();
+            usage(0);
             /*NOTREACHED*/
         }
 
     if (argc - optind < 2)
-        usage();
+        usage(-1);
 
     out = TIFFOpen(argv[argc-1], "w");
     if (out == NULL)
@@ -155,7 +161,7 @@ cvt_by_tile( TIFF *in, TIFF *out )
      * mirroring pass.
      */
     wrk_line = (uint32*)_TIFFmalloc(tile_width * sizeof (uint32));
-    if (wrk_line == 0) {
+    if (!wrk_line) {
         TIFFError(TIFFFileName(in), "No space for raster scanline buffer");
         ok = 0;
     }
@@ -167,7 +173,7 @@ cvt_by_tile( TIFF *in, TIFF *out )
     {
         for( col = 0; ok && col < width; col += tile_width )
         {
-            int		i_row;
+            uint32 i_row;
 
             /* Read the tile into an RGBA array */
             if (!TIFFReadRGBATile(in, col, row, raster)) {
@@ -246,7 +252,7 @@ cvt_by_strip( TIFF *in, TIFF *out )
      * mirroring pass.
      */
     wrk_line = (uint32*)_TIFFmalloc(width * sizeof (uint32));
-    if (wrk_line == 0) {
+    if (!wrk_line) {
         TIFFError(TIFFFileName(in), "No space for raster scanline buffer");
         ok = 0;
     }
@@ -321,9 +327,7 @@ cvt_whole_image( TIFF *in, TIFF *out )
 {
     uint32* raster;			/* retrieve RGBA image */
     uint32  width, height;		/* image width & height */
-    uint32	row;
-    uint32  *wrk_line;
-        
+    uint32  row;
         
     TIFFGetField(in, TIFFTAG_IMAGEWIDTH, &width);
     TIFFGetField(in, TIFFTAG_IMAGELENGTH, &height);
@@ -338,34 +342,12 @@ cvt_whole_image( TIFF *in, TIFF *out )
     }
 
     /* Read the image in one chunk into an RGBA array */
-    if (!TIFFReadRGBAImage(in, width, height, raster, 0)) {
+    if (!TIFFReadRGBAImageOriented(in, width, height, raster,
+                                   ORIENTATION_TOPLEFT, 0)) {
         _TIFFfree(raster);
         return (0);
     }
 
-    /* For some reason the TIFFReadRGBAImage() function chooses the
-       lower left corner as the origin.  Vertically mirror scanlines. */
-
-    wrk_line = (uint32*)_TIFFmalloc(width * sizeof (uint32));
-    if (wrk_line == 0) {
-        TIFFError(TIFFFileName(in), "No space for raster scanline buffer");
-        return (0);
-    }
-    
-    for( row = 0; row < height / 2; row++ )
-    {
-        uint32	*top_line, *bottom_line;
-
-        top_line = raster + width * row;
-        bottom_line = raster + width * (height-row-1);
-
-        _TIFFmemcpy(wrk_line, top_line, 4*width);
-        _TIFFmemcpy(top_line, bottom_line, 4*width);
-        _TIFFmemcpy(bottom_line, wrk_line, 4*width);
-    }
-
-    _TIFFfree( wrk_line );
-
     /*
     ** Do we want to strip away alpha components?
     */
@@ -473,27 +455,32 @@ tiffcvt(TIFF* in, TIFF* out)
             return( cvt_whole_image( in, out ) );
 }
 
-static char* usageMsg[] = {
-    "usage: tiff2rgba [-c comp] [-r rows] [-b] input... output\n",
-    "where comp is one of the following compression algorithms:\n",
-    " jpeg\t\tJPEG encoding\n",
-    " zip\t\tLempel-Ziv & Welch encoding\n",
-    " lzw\t\tLempel-Ziv & Welch encoding\n",
-    " (lzw compression unsupported by default due to Unisys patent enforcement)\n",
-    " packbits\tPackBits encoding\n",
-    " none\t\tno compression\n",
-    "and the other options are:\n",
-    " -r\trows/strip\n",
-    " -b (progress by block rather than as a whole image)\n",
-    " -n don't emit alpha component.\n",
+static char* stuff[] = {
+    "usage: tiff2rgba [-c comp] [-r rows] [-b] input... output",
+    "where comp is one of the following compression algorithms:",
+    " jpeg\t\tJPEG encoding",
+    " zip\t\tLempel-Ziv & Welch encoding",
+    " lzw\t\tLempel-Ziv & Welch encoding",
+    " packbits\tPackBits encoding",
+    " none\t\tno compression",
+    "and the other options are:",
+    " -r\trows/strip",
+    " -b (progress by block rather than as a whole image)",
+    " -n don't emit alpha component.",
     NULL
 };
 
 static void
-usage(void)
+usage(int code)
 {
+	char buf[BUFSIZ];
 	int i;
-	for (i = 0; usageMsg[i]; i++)
-		fprintf(stderr, "%s", usageMsg[i]);
-	exit(-1);
+
+	setbuf(stderr, buf);
+        fprintf(stderr, "%s\n\n", TIFFGetVersion());
+	for (i = 0; stuff[i] != NULL; i++)
+		fprintf(stderr, "%s\n", stuff[i]);
+	exit(code);
 }
+
+/* vim: set ts=8 sts=8 sw=8 noet: */
